//chemesis2
include rest-SIgraphs.g

//effect of concentration change on resting potential.  Units are mM, Volts, Seimens,Ohms,meters

/*initial (default) concentrations*/
float quantUnits=1
float Kin0 = 90
float Kout0 = 2.5
float clout0 = 120
float clin0 = 3.3

float gbarK=30  /* siemens /m^2 */
float gbarCl=18
float PI	= 3.14159

/*cell parameters, assume sphere*/
float LengthUnits=1
float radius = 25e-6 /* units are m, thus diameter is 50 microns */
float surface = 4*PI*{radius}*{radius}
float volume = (4.0/3.0)*{surface}*{radius}
float RM = 2	    /* ohm-cm^2 */
float CM = 0.01     /* Farad/m^2 */

/*parameters of extracellular space*/
float eclen = 0.1	/* 1 mm */
float ecradius = 1.0
float ecarea = PI*{ecradius}*{eclen}
float ecvol = {ecarea}*{ecradius}	

create neutral cell
ce cell

/* concentration compartments*/
create rxnpool kin 
setfield kin radius {radius} \
	vol {volume} \
	SAout {surface}  \
	Cinit {Kin0} \
    Iunits 1 \
    Dunits {LengthUnits} \
    units {quantUnits}

create rxnpool clin 
setfield clin radius {radius} \
	vol {volume} \
	SAout {surface}  \
	Cinit {clin0}  \
    Iunits 1 \
    Dunits {LengthUnits} \
    units {quantUnits}

create rxnpool kout	
setfield kout radius {ecradius}	\
	vol {ecvol}	\
	SAout {ecarea}	\
	SAin {surface}	\
	len {eclen}	\
	Cinit {Kout0}  \
    Iunits 1 \
    Dunits {LengthUnits} \
    units {quantUnits}

create rxnpool clout     
setfield clout radius {ecradius}       \
	vol {ecvol}     \
	SAout {ecarea}  \
	SAin {surface}  \
	len {eclen}     \
	Cinit {clout0} \
    Iunits 1 \
    Dunits {LengthUnits} \
    units {quantUnits}

/* voltage compartment*/
create compartment vm 
setfield vm Rm {RM/surface} Cm {CM*surface} dia {2*radius} Em -0.090

/* potassium and chloride channels*/
create nernst krev 
setfield krev scale 1 T 20 valency 1
create vdep_channel kchan
setfield kchan gbar {gbarK*surface}
create nernst clrev 
setfield clrev scale 1 T 20 valency -1
create vdep_channel clchan 
setfield clchan gbar {gbarCl*surface}	

/* or could use ghk object instead:
create ghk kperm p {some value}
create ghk clperm p {some value}
addmsg kin kperm CIN Conc
addmsg kout kperm COUT Conc
addmsg vm kperm VOLTAGE Vm
addmsg kperm vm CHANNEL Ek Gk
addmsg clin clperm CIN Conc
addmsg clout clperm COUT Conc
addmsg vm clperm VOLTAGE Vm
addmsg clperm vm CHANNEL Ek Gk

current must be in units of nanoamps:
addmsg kperm kin CURRENT 1 Ik
addmsg kperm kout CURRENT -1 Ik
addmsg clperm clin CURRENT -1 Ik
addmsg clperm clout CURRENT 1 Ik
*/

/*messages between compartments*/
addmsg kin krev CIN Conc
addmsg kout krev COUT Conc
addmsg clin clrev CIN Conc
addmsg clout clrev COUT Conc
addmsg vm kchan VOLTAGE Vm
addmsg vm clchan VOLTAGE Vm
addmsg krev kchan EK E
addmsg clrev clchan EK E
addmsg kchan vm CHANNEL Gk Ek
addmsg clchan vm CHANNEL Gk Ek

//current must be in units of nanoamps: 
/* need to define charge as negative of actual charge because of interaction
 between vdep_channel and rxnpool */
addmsg kchan kin CURRENT -1 Ik
addmsg kchan kout CURRENT 1 Ik
addmsg clchan clin CURRENT 1 Ik
addmsg clchan clout CURRENT -1 Ik 

make_graphs
make_control

setclock 0 0.001
reset
